@@ -1,5 +1,5 @@
 /* board.cc -- game board for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2013 Gerardo Ballabio
+   Copyright (C) 2011-2014 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -132,6 +132,11 @@ void game_board::next_level()
 	case 2: ++bmin; break;
 	}
       break;
+    case 2:
+      // increase superblock size
+      ++bsuper;
+      next_blockset();
+      break;
     }
 }
 
@@ -155,7 +160,7 @@ void game_board::next_blockset()
 
 int game_board::score_block() const
 {
-  return (speed + bmax * 5) * (bmax + bmin - 5) / (1 + empty);
+  return (speed + bmax * 5 + bsuper) * (bmax + bmin - 5) / (1 + empty);
 }
 
 int game_board::score_lines(int lines) const
@@ -206,9 +211,15 @@ void game_board::start_game(const group *gg, int width, int depth,
     min = max;
   bmin = min;
   bmax = nsize = max;
+  isuper = bsuper = 0;
   empty = e;
   // start game
   mode1 = m1;
+  if (mode1 == 2)
+    {
+      bsuper = max + 1;
+      next_blockset();
+    }
   mode2 = m2;
   speed = s;
   level = (mode1 == 0) ? speed : 1;
@@ -355,13 +366,23 @@ void game_board::next_block()
     game = false;
 
   // next block
-  // cycle over block sizes (not in order)
-  int plus = (bmax - bmin + 1) / 2, minus = plus * 2 + 1;
-  nsize += plus;
-  if (nsize > bmax)
-    nsize -= minus;
-  if (nsize < bmin)
-    nsize += (plus > 0) ? plus : 1;
+  int max_super = (bsuper < 10) ? bsuper : 10;
+  if (mode1 == 2 && ++isuper >= max_super)
+    {
+      // superblock
+      isuper = 0;
+      nsize = bsuper;
+    }
+  else
+    {
+      // cycle over block sizes (not in order)
+      int plus = (bmax - bmin + 1) / 2, minus = plus * 2 + 1;
+      nsize += plus;
+      while (nsize > bmax)
+	nsize -= minus;
+      if (nsize < bmin)
+	nsize += (plus > 0) ? plus : 1;
+    }
   // choose block
   nblock = rand() % series[nsize];
   for (int i=0; i<nsize; ++i)
