@@ -1,5 +1,5 @@
 /* preferences.h -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2013 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -56,10 +56,10 @@ private:
   ; ; ; ; ; ; ; Gtk::SpinButton depth_spin;
   ; ; ; ; ; ; ; Gtk::Adjustment depth_adjust;
 
-  ; ; Gtk::VBox level_box1;
-  ; ; ; Gtk::Label level_heading;
-  ; ; ; Gtk::Alignment level_align;
-  ; ; ; ; Gtk::VBox level_box2;
+  ; ; Gtk::VBox game_box1;
+  ; ; ; Gtk::Label game_heading;
+  ; ; ; Gtk::Alignment game_align;
+  ; ; ; ; Gtk::VBox game_box2;
   ; ; ; ; ; Gtk::HBox mode_box1;
   ; ; ; ; ; ; Gtk::Label mode_label1;
   ; ; ; ; ; ; Gtk::ComboBoxText mode_combo1;
@@ -79,19 +79,19 @@ private:
   ; ; ; ; ; ; Gtk::Label bricks_label2;
   ; ; ; ; ; ; Gtk::SpinButton bricks_spin2;
   ; ; ; ; ; ; Gtk::Adjustment bricks_adjust2;
-
-  ; ; Gtk::VBox game_box1;
-  ; ; ; Gtk::Label game_heading;
-  ; ; ; Gtk::Alignment game_align;
-  ; ; ; ; Gtk::VBox game_box2;
-  ; ; ; ; ; Gtk::CheckButton next_check;
-  ; ; ; ; ; Gtk::CheckButton land_check;
   ; ; ; ; ; Gtk::HBox empty_box;
   ; ; ; ; ; ; Gtk::Label empty_label1;
   ; ; ; ; ; ; Gtk::SpinButton empty_spin;
   ; ; ; ; ; ; Gtk::Adjustment empty_adjust;
   ; ; ; ; ; ; Gtk::Label empty_label2;
 
+  ; ; Gtk::VBox view_box1;
+  ; ; ; Gtk::Label view_heading;
+  ; ; ; Gtk::Alignment view_align;
+  ; ; ; ; Gtk::VBox view_box2;
+  ; ; ; ; ; Gtk::CheckButton next_check;
+  ; ; ; ; ; Gtk::CheckButton land_check;
+
   // second tab
   ; Gtk::VBox tab_controls;
   ; ; Gtk::VBox controls_box;
@@ -142,9 +142,9 @@ public:
   int get_speed() const { return speed_spin.get_value_as_int(); }
   int get_bricks_max() const { return bricks_spin1.get_value_as_int(); }
   int get_bricks_min() const { return bricks_spin2.get_value_as_int(); }
+  int get_empty() const { return empty_spin.get_value_as_int(); }
   bool get_next() const { return next_check.get_active(); }
   bool get_land() const { return land_check.get_active(); }
-  int get_empty() const { return empty_spin.get_value_as_int(); }
   unsigned get_key_2d(int n) const;
   unsigned get_key_3d(int n) const;
 
