@@ -22,6 +22,8 @@
 #include <libxml++/parsers/textreader.h>
 #include "scores.h"
 
+#include <iostream>
+
 bool ScoresDialog::pass(const std::vector<game>::const_iterator &i) const
 {
   // get current filters
@@ -113,7 +115,7 @@ bool ScoresDialog::on_expose_event(GdkEventExpose *event)
   tree.get_cell_area(Gtk::TreeModel::Path("0"), *tree.get_column(0),
 		     rectangle);
   // some more space for headers and scrollbar
-  int h = rectangle.get_height() * (visible_rows + 2), w = min_w;
+  int h = (rectangle.get_height() + 6) * (visible_rows + 1) + 6, w = min_w;
   if (h < min_h)
     h = min_h;
   int x, y;
@@ -303,7 +305,7 @@ ScoresDialog::ScoresDialog()
   empty_label2.set_label("empty cells");
 
   // board
-  get_vbox()->pack_start(scroll, Gtk::PACK_SHRINK);
+  get_vbox()->pack_start(scroll);
   scroll.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
   scroll.add(tree);
   list = Gtk::ListStore::create(columns);
